@@ -8,12 +8,12 @@
 #' 
 #' The subcortical component (NIFTI) is not resampled.
 #'
-#' @inheritSection Connectome_Workbench_Description Connectome Workbench Requirement
 #' 
 #' @inheritParams cifti_fname_Param
 #' @inheritParams surfL_fname_Param
 #' @inheritParams surfR_fname_Param
 #' @inheritParams brainstructures_Param_LR
+#' @inheritParams idx_Param
 #' @inheritParams resamp_res_Param_optional
 #' @param mwall_values If the medial wall locations are not indicated in the
 #'  CIFTI, use these values to infer the medial wall mask. Default: 
@@ -27,7 +27,7 @@
 #' 
 read_cifti_separate <- function(
   cifti_fname, surfL_fname=NULL, surfR_fname=NULL,
-  brainstructures=c("left","right"),
+  brainstructures=c("left","right"), idx=NULL,
   resamp_res=NULL, mwall_values=c(NA, NaN), verbose=TRUE) {
 
   # ----------------------------------------------------------------------------
@@ -150,11 +150,9 @@ read_cifti_separate <- function(
   # ----------------------------------------------------------------------------
   # make_xifti() ---------------------------------------------------------------
   # ----------------------------------------------------------------------------
-
-  to_read <- as.list(to_read)
   
   to_read["mwall_values"] <- list(mwall_values=mwall_values)
-  to_read$cifti_info$cifti <- cifti_info$cifti
+  to_read$cifti_info <- cifti_info
   # Erase misc metadata and replace with the name of the resampled file
   to_read$cifti_info$cifti$misc <- list(resampled_fname=cifti_fname)
 
@@ -163,15 +161,28 @@ read_cifti_separate <- function(
   names(to_read)[names(to_read) == "ROIcortexR"] <- "cortexR_mwall"
   names(to_read)[names(to_read) == "ROIsubcortVol"] <- "subcortMask"
 
-  if (!is.null(surfL_fname)) { to_read["surfL"] <- surfL_fname }
-  if (!is.null(surfR_fname)) { to_read["surfR"] <- surfR_fname }
-
   # Read the CIFTI file from the separated files.
   if (verbose) { cat("Reading GIFTI and NIFTI files to form the CIFTI.\n") }
+
+  if (!is.null(idx)) {
+    to_read$idx <- idx
+    if (!is.null(to_read$cifti_info$cifti$names)) {
+      to_read$cifti_info$cifti$names <- to_read$cifti_info$cifti$names[idx]
+    }
+    if (!is.null(to_read$cifti_info$cifti$labels)) {
+      to_read$cifti_info$cifti$labels <- to_read$cifti_info$cifti$labels[idx]
+    }
+  }
   xifti <- do.call(make_xifti, to_read)
 
+  if (!is.null(surfL_fname)) { add_surf(xifti, surfL=surfL_fname) }
+  if (!is.null(surfR_fname)) { add_surf(xifti, surfR=surfR_fname) }
+
   if ("left" %in% brainstructures || "right" %in% brainstructures) {
-    xifti$meta$cortex$resamp_res <- resamp_res
+    xifti$meta$cortex["resamp_res"] <- list(resamp_res)
+  }
+  if ("subcort" %in% brainstructures) {
+    xifti$meta$subcort[c("labels", "mask", "trans_mat")] <- to_read$cifti_info$subcort[c("labels", "mask", "trans_mat")]
   }
 
   if (verbose) {
